file_to_key_value_map

Function file_to_key_value_map 

pub fn file_to_key_value_map(
    path: &Path,
) -> Result<HashMap<Box<str>, Box<str>>, Error>
Parses a key-value file into a hash map.

Reads the file at path and delegates to text_to_key_value_map for parsing.

Errors

This function will return an error if:

  • The file cannot be opened (Error::OpeningFile)
  • An I/O error occurs while reading (Error::ReadingFile)
  • A duplicate key is found in the file (Error::MultipleKeys)